#!/usr/bin/perl

use strict;
use warnings;

use DirTreeTestApp;

my $app = DirTreeTestApp->new;
$app->MainLoop;
